zabbix_export:
  version: '7.0'
  template_groups:
    - uuid: 7c2cb727f85b492d88cd56e17127c64d
      name: Templates/SAN
  templates:
    - uuid: 10537641cfa3416ab0f1451cdb61d804
      template: 'HPE MSA 2060 Storage by HTTP'
      name: 'HPE MSA 2060 Storage by HTTP'
      description: |
        The template to monitor HPE MSA 2060 by HTTP.
        It works without any external scripts and uses the script item.
        
        Setup:
        1. Create a user with a monitor role on the storage, for example "zabbix".
        2. Link the template to a host.
        3. Set the hostname or IP address of the host in the {$HPE.MSA.API.HOST} macro and configure the username and password in the {$HPE.MSA.API.USERNAME} and {$HPE.MSA.API.PASSWORD} macros.
        4. Change the {$HPE.MSA.API.SCHEME} and {$HPE.MSA.API.PORT} macros if needed.
        
        You can discuss this template or leave feedback on our forum https://www.zabbix.com/forum/zabbix-suggestions-and-feedback
        
        Generated by official Zabbix template tool "Templator"
      vendor:
        name: Zabbix
        version: 7.0-0
      groups:
        - name: Templates/SAN
      items:
        - uuid: e869b8e7cc7643ea805532c941fa0e16
          name: 'Get disk group statistics'
          type: DEPENDENT
          key: hpe.msa.disks.get.groups.statistics
          history: '0'
          value_type: TEXT
          description: 'Disk groups statistics data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''disk-group-statistics'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 098d8c93634e4a3ab69b39f2d813f81c
          name: 'Get controllers'
          type: DEPENDENT
          key: hpe.msa.get.controllers
          history: '0'
          value_type: TEXT
          description: 'Controllers data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''controllers'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 61fe1e0cf61441c58cbd754805fefe9d
          name: 'Get controller statistics'
          type: DEPENDENT
          key: hpe.msa.get.controller_statistics
          history: '0'
          value_type: TEXT
          description: 'Controllers statistics data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''controller-statistics'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: bafec666b170480f941fe25cb3cf903d
          name: 'Get data'
          type: SCRIPT
          key: hpe.msa.get.data
          history: '0'
          value_type: TEXT
          params: |
            var params = JSON.parse(value),
            	fields = ['username', 'password', 'base_url'],
            	methods = [
            		'system',
            		'controllers',
            		'controller-statistics',
            		'frus',
            		'disk-groups',
            		'disk-group-statistics',
            		'disks',
            		'enclosures',
            		'fans',
            		'pools',
            		'ports',
            		'power-supplies',
            		'volumes',
            		'volume-statistics'
            	],
            	result = {},
            	data = {};
            
            fields.forEach(function (field) {
            	if (typeof params !== 'object' || typeof params[field] === 'undefined' || params[field] === '') {
            		throw 'Required param is not set: "' + field + '".';
            	}
            });
            
            if (!params.base_url.endsWith('/')) {
            	params.base_url += '/';
            }
            
            var response, request = new HttpRequest();
            request.addHeader('datatype: json');
            
            auth_string = sha256(params.username + '_' + params.password);
            
            response = request.get(params.base_url + 'api/login/' + auth_string);
            
            if (request.getStatus() < 200 || request.getStatus() >= 300) {
            	throw 'Authentication request has failed with status code ' + request.getStatus() + ': ' + response;
            }
            
            if (response !== null) {
            	try {
            		auth_data = JSON.parse(response);
            	}
            	catch (error) {
            		throw 'Failed to parse authentication response received from device API.';
            	}
            }
            
            session_key = auth_data['status'][0]['response'];
            
            request.addHeader('sessionKey: ' + session_key);
            
            data.errors = [];
            
            methods.forEach(function (method) {
            	response = request.get(params.base_url + 'api/show/' + method);
            	method_error = '';
            
            	if (request.getStatus() < 200 || request.getStatus() >= 300) {
            		method_error = 'Method: ' + method + '. Request has failed with status code ' + request.getStatus() + ': ' + response;
            		data.errors.push(method_error);
            		return;
            	}
            
            	if (response !== null) {
            		try {
            			result = JSON.parse(response);
            			switch (method) {
            				case 'controller-statistics':
            					var stats_array = result['controller-statistics'] || [];
            					for (var i = 0; i < stats_array.length; i++) {
            						result['controller-statistics'][i]['durable-id'] = result['controller-statistics'][i]['durable-id'].toLowerCase();
            					}
            					data[method] = result[method];
            					break;
            				case 'frus':
            					data[method] = result['enclosure-fru'];
            					break;
            				case 'disks':
            					data[method] = result['drives'];
            					break;
            				case 'fans':
            					data[method] = result['fan'];
            					break;
            				case 'ports':
            					data[method] = result['port'];
            					break;
            				default:
            					data[method] = result[method];
            			}
            		}
            		catch (error) {
            			method_error = 'Method: ' + method + '. Failed to parse response received from device API.';
            		}
            	}
            	else {
            		method_error = 'Method: ' + method + '. No data received by request.';
            	}
            
            	if (method_error.length > 0) {
            		data.errors.push(method_error);
            	}
            });
            
            if (data.errors.length == 0) {
            	data.errors = '';
            }
            
            return JSON.stringify(data);
          description: 'The JSON with result of API requests.'
          timeout: '{$HPE.MSA.DATA.TIMEOUT}'
          parameters:
            - name: base_url
              value: '{$HPE.MSA.API.SCHEME}://{$HPE.MSA.API.HOST}:{$HPE.MSA.API.PORT}/'
            - name: password
              value: '{$HPE.MSA.API.PASSWORD}'
            - name: username
              value: '{$HPE.MSA.API.USERNAME}'
          tags:
            - tag: component
              value: raw
        - uuid: b3488b287d7b48f2a26cbc39b62c4a67
          name: 'Get disks'
          type: DEPENDENT
          key: hpe.msa.get.disks
          history: '0'
          value_type: TEXT
          description: 'Disks data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''disks'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 98f1f30231e6419cb8a91bb0a9127985
          name: 'Get disk groups'
          type: DEPENDENT
          key: hpe.msa.get.disks.groups
          history: '0'
          value_type: TEXT
          description: 'Disk groups data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''disk-groups'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 376ca0be12304701bd7c9fc6c1743428
          name: 'Get enclosures'
          type: DEPENDENT
          key: hpe.msa.get.enclosures
          history: '0'
          value_type: TEXT
          description: 'Enclosures data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''enclosures'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 078dd015f25d4778af429f9b5e391bc5
          name: 'Get method errors'
          type: DEPENDENT
          key: hpe.msa.get.errors
          value_type: TEXT
          description: 'A list of method errors from API requests.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''errors'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: errors
          triggers:
            - uuid: 2133ddf10a3641d78e609948d6842687
              expression: 'length(last(/HPE MSA 2060 Storage by HTTP/hpe.msa.get.errors))>0'
              name: 'There are errors in method requests to API'
              priority: AVERAGE
              description: 'There are errors in method requests to API.'
              dependencies:
                - name: 'Service is down or unavailable'
                  expression: 'max(/HPE MSA 2060 Storage by HTTP/net.tcp.service["{$HPE.MSA.API.SCHEME}","{$HPE.MSA.API.HOST}","{$HPE.MSA.API.PORT}"],5m)=0'
              tags:
                - tag: scope
                  value: availability
        - uuid: 7bc300f30a804cdd8acbba20b6d45f4c
          name: 'Get fans'
          type: DEPENDENT
          key: hpe.msa.get.fans
          history: '0'
          value_type: TEXT
          description: 'Fans data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''fans'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 41ec35cca22d4e6fb22a4e3759718a36
          name: 'Get FRU'
          type: DEPENDENT
          key: hpe.msa.get.fru
          history: '0'
          value_type: TEXT
          description: 'FRU data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''frus'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 09804c2149264387a81de7df98a07739
          name: 'Get pools'
          type: DEPENDENT
          key: hpe.msa.get.pools
          history: '0'
          value_type: TEXT
          description: 'Pools data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''pools'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: c208ba831d534da9a8a650b31b7f4e8c
          name: 'Get ports'
          type: DEPENDENT
          key: hpe.msa.get.ports
          history: '0'
          value_type: TEXT
          description: 'Ports data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''ports'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 7cafbbb815324dc89f0db58384fe2e48
          name: 'Get power supplies'
          type: DEPENDENT
          key: hpe.msa.get.power_supplies
          history: '0'
          value_type: TEXT
          description: 'Power supplies data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''power-supplies'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 8dd7fafd33144838a1b382cc75e551d7
          name: 'Get system'
          type: DEPENDENT
          key: hpe.msa.get.system
          history: '0'
          value_type: TEXT
          description: 'The system data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.system[0]'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: b7e65fee619b47fab8551df9bdd5d4cb
          name: 'Get volumes'
          type: DEPENDENT
          key: hpe.msa.get.volumes
          history: '0'
          value_type: TEXT
          description: 'Volumes data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''volumes'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 052e68cc870149718239fd9567da6fce
          name: 'Get volume statistics'
          type: DEPENDENT
          key: hpe.msa.get.volumes.statistics
          history: '0'
          value_type: TEXT
          description: 'Volumes statistics data.'
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''volume-statistics'']'
              error_handler: DISCARD_VALUE
          master_item:
            key: hpe.msa.get.data
          tags:
            - tag: component
              value: raw
        - uuid: 4c8b2c72135a4af781c0f31730366abe
          name: 'System contact'
          type: DEPENDENT
          key: hpe.msa.system.contact
          value_type: CHAR
          description: 'The name of the person who administers the system.'
          inventory_link: CONTACT
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''system-contact'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: system
        - uuid: dc310d8c55a74a00bed9c004ba33d1fa
          name: 'System health'
          type: DEPENDENT
          key: hpe.msa.system.health
          description: 'System health status.'
          valuemap:
            name: Health
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''health-numeric'']'
              error_handler: CUSTOM_VALUE
              error_handler_params: '4'
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: health
            - tag: component
              value: system
          triggers:
            - uuid: 49e8c1d8a14f40b5acb2723e370ccccb
              expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.system.health)=1'
              name: 'System health is in degraded state'
              priority: WARNING
              description: 'System health is in degraded state.'
              tags:
                - tag: scope
                  value: performance
            - uuid: 2709a971f2ce417d8e269a0e5ebdd964
              expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.system.health)=2'
              name: 'System health is in fault state'
              priority: AVERAGE
              description: 'System health is in fault state.'
              tags:
                - tag: scope
                  value: availability
            - uuid: fa35428a4f41453984bd0bfa566e0674
              expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.system.health)=3'
              name: 'System health is in unknown state'
              priority: INFO
              description: 'System health is in unknown state.'
              tags:
                - tag: scope
                  value: notice
        - uuid: c4aae4a5f218472698751d9de8d1087d
          name: 'System information'
          type: DEPENDENT
          key: hpe.msa.system.info
          value_type: CHAR
          description: 'A brief description of what the system is used for or how it is configured.'
          inventory_link: NOTES
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''system-information'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: system
        - uuid: 3768f170e5ef44bca39e89b1f8973e6d
          name: 'System location'
          type: DEPENDENT
          key: hpe.msa.system.location
          value_type: CHAR
          description: 'The location of the system.'
          inventory_link: LOCATION
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''system-location'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: system
        - uuid: 00c58217d52e4cd5852bdd9c71c4375f
          name: 'System name'
          type: DEPENDENT
          key: hpe.msa.system.name
          value_type: CHAR
          description: 'The name of the storage system.'
          inventory_link: NAME
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''system-name'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: system
        - uuid: 103e58d547284e68b079e92074950ff9
          name: 'Product ID'
          type: DEPENDENT
          key: hpe.msa.system.product_id
          value_type: CHAR
          description: 'The product model identifier.'
          inventory_link: MODEL
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''product-id'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: system
        - uuid: 7865d8ae697c40c5b5855c47bb82ccc4
          name: 'Vendor name'
          type: DEPENDENT
          key: hpe.msa.system.vendor_name
          value_type: CHAR
          description: 'The vendor name.'
          inventory_link: VENDOR
          preprocessing:
            - type: JSONPATH
              parameters:
                - '$.[''vendor-name'']'
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1d
          master_item:
            key: hpe.msa.get.system
          tags:
            - tag: component
              value: system
        - uuid: 3831060089ff497993088472e922df38
          name: 'Service ping'
          type: SIMPLE
          key: 'net.tcp.service["{$HPE.MSA.API.SCHEME}","{$HPE.MSA.API.HOST}","{$HPE.MSA.API.PORT}"]'
          description: 'Check if HTTP/HTTPS service accepts TCP connections.'
          preprocessing:
            - type: DISCARD_UNCHANGED_HEARTBEAT
              parameters:
                - 1h
          tags:
            - tag: component
              value: health
            - tag: component
              value: network
          triggers:
            - uuid: 9c1bf26f95d946f386bbf613d3d55779
              expression: 'max(/HPE MSA 2060 Storage by HTTP/net.tcp.service["{$HPE.MSA.API.SCHEME}","{$HPE.MSA.API.HOST}","{$HPE.MSA.API.PORT}"],5m)=0'
              name: 'Service is down or unavailable'
              priority: HIGH
              description: 'HTTP/HTTPS service is down or unable to establish TCP connection.'
              tags:
                - tag: scope
                  value: availability
      discovery_rules:
        - uuid: 91c30dd0509843898601ce6d489fab03
          name: 'Controllers discovery'
          type: DEPENDENT
          key: hpe.msa.controllers.discovery
          description: 'Discover controllers.'
          item_prototypes:
            - uuid: 73bc16fc631f4386abbc78897db07e13
              name: 'Controller [{#CONTROLLER.ID}]: Cache: Read hits, rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cache.read.hits["{#CONTROLLER.ID}",rate]'
              description: 'For the controller that owns the volume, the number of times the block to be read is found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''read-cache-hits'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 04e14fe4d8ba4693b954ebcac1671649
              name: 'Controller [{#CONTROLLER.ID}]: Cache: Read misses, rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cache.read.misses["{#CONTROLLER.ID}",rate]'
              description: 'For the controller that owns the volume, the number of times the block to be read is not found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''read-cache-misses'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 5cb9f7eb42d2413a90161ac192629073
              name: 'Controller [{#CONTROLLER.ID}]: Cache: Write hits, rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cache.write.hits["{#CONTROLLER.ID}",rate]'
              description: 'For the controller that owns the volume, the number of times the block written to is found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''write-cache-hits'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 61aa7235c6c44cfababd1b2390cc0443
              name: 'Controller [{#CONTROLLER.ID}]: Cache: Write misses, rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cache.write.misses["{#CONTROLLER.ID}",rate]'
              description: 'For the controller that owns the volume, the number of times the block written to is not found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''write-cache-misses'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 0d754544c18143ff98114e1ed316ad1e
              name: 'Controller [{#CONTROLLER.ID}]: Cache: Write utilization'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cache.write["{#CONTROLLER.ID}",util]'
              units: '%'
              description: 'Percentage of write cache in use, from 0 to 100.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''write-cache-used'']'
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 482c5af99fe740278c4663ba300dee04
              name: 'Controller [{#CONTROLLER.ID}]: Cache memory size'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cache["{#CONTROLLER.ID}",total]'
              units: B
              description: 'Controller cache memory size.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''cache-memory-size'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
                - type: MULTIPLIER
                  parameters:
                    - '1048576'
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 80d6ae014e354f6c844c3b88ea66c530
              name: 'Controller [{#CONTROLLER.ID}]: CPU utilization'
              type: DEPENDENT
              key: 'hpe.msa.controllers.cpu["{#CONTROLLER.ID}",util]'
              units: '%'
              description: 'Percentage of time the CPU is busy, from 0 to 100.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''cpu-load'']'
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
              trigger_prototypes:
                - uuid: 0bf68b46b7644ad5ad0123df49c1da35
                  expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers.cpu["{#CONTROLLER.ID}",util],5m)>{$HPE.MSA.CONTROLLER.CPU.UTIL.CRIT}'
                  name: 'Controller [{#CONTROLLER.ID}]: High CPU utilization'
                  event_name: 'Controller [{#CONTROLLER.ID}]: High CPU utilization (over {$HPE.MSA.CONTROLLER.CPU.UTIL.CRIT}% for 5m)'
                  priority: WARNING
                  description: 'Controller CPU utilization is too high. The system might be slow to respond.'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: c8fbfd459fce4149b1459e366b61981a
              name: 'Controller [{#CONTROLLER.ID}]: Data transfer rate: Reads'
              type: DEPENDENT
              key: 'hpe.msa.controllers.data_transfer.reads["{#CONTROLLER.ID}",rate]'
              value_type: FLOAT
              units: Bps
              description: 'The data read rate, in bytes per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''data-read-numeric'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 9c5c23273f5b43ad9e300d2c7b90bc3f
              name: 'Controller [{#CONTROLLER.ID}]: Data transfer rate: Total'
              type: DEPENDENT
              key: 'hpe.msa.controllers.data_transfer.total["{#CONTROLLER.ID}",rate]'
              units: Bps
              description: 'The data transfer rate, in bytes per second, calculated over the interval since these statistics were last requested or reset. This value will be zero if it has not been requested or reset since a controller restart.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''bytes-per-second-numeric'']'
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 94f0b7f7d397453f9227c1b473a77a4e
              name: 'Controller [{#CONTROLLER.ID}]: Data transfer rate: Writes'
              type: DEPENDENT
              key: 'hpe.msa.controllers.data_transfer.writes["{#CONTROLLER.ID}",rate]'
              value_type: FLOAT
              units: Bps
              description: 'The data write rate, in bytes per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''data-written-numeric'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 8b0f014d1ed5470d919357f204b704ca
              name: 'Controller [{#CONTROLLER.ID}]: IOPS, read rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.iops.read["{#CONTROLLER.ID}",rate]'
              value_type: FLOAT
              units: '!r/s'
              description: 'Number of read operations per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-reads'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 16f2fd5bd9d244daa09aef3f79a5d450
              name: 'Controller [{#CONTROLLER.ID}]: IOPS, total rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.iops.total["{#CONTROLLER.ID}",rate]'
              units: '!iops'
              description: 'Input/output operations per second, calculated over the interval since these statistics were last requested or reset. This value will be zero if it has not been requested or reset since a controller restart.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''iops'']'
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 9b8366ac60304c3c98dedc278ad18418
              name: 'Controller [{#CONTROLLER.ID}]: IOPS, write rate'
              type: DEPENDENT
              key: 'hpe.msa.controllers.iops.write["{#CONTROLLER.ID}",rate]'
              value_type: FLOAT
              units: '!w/s'
              description: 'Number of write operations per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-writes'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 5f6c124f1aef41499ee52616ede02de9
              name: 'Controller [{#CONTROLLER.ID}]: Disks'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",disks]'
              description: 'Number of disks in the storage system.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''disks'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: c70f280c9c494b769b442f3a22a3c173
              name: 'Controller [{#CONTROLLER.ID}]: Disk groups'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",disk_groups]'
              description: 'Number of disk groups in the storage system.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''virtual-disks'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: ba1bb9818a9a487c8742d619316b087e
              name: 'Controller [{#CONTROLLER.ID}]: Firmware version'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",firmware]'
              value_type: CHAR
              description: 'Storage controller firmware version.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''sc-fw'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 5f5307f2904a4792af1906a2b03a2a9b
              name: 'Controller [{#CONTROLLER.ID}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",health]'
              description: 'Controller health status.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: component
                  value: health
                - tag: controller
                  value: '{#CONTROLLER.ID}'
              trigger_prototypes:
                - uuid: 3988a5b897a34c84952fa573d7019879
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",health])=1'
                  name: 'Controller [{#CONTROLLER.ID}]: Controller health is in degraded state'
                  priority: WARNING
                  description: 'Controller health is in degraded state.'
                  dependencies:
                    - name: 'Controller [{#CONTROLLER.ID}]: Controller is down'
                      expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",status])=1'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 7256e023ac82427bb6ee923d4ff07786
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",health])=2'
                  name: 'Controller [{#CONTROLLER.ID}]: Controller health is in fault state'
                  priority: AVERAGE
                  description: 'Controller health is in fault state.'
                  dependencies:
                    - name: 'Controller [{#CONTROLLER.ID}]: Controller is down'
                      expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",status])=1'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 15bc89e6c61549caaf5a66c85446ea9d
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",health])=3'
                  name: 'Controller [{#CONTROLLER.ID}]: Controller health is in unknown state'
                  priority: INFO
                  description: 'Controller health is in unknown state.'
                  dependencies:
                    - name: 'Controller [{#CONTROLLER.ID}]: Controller is down'
                      expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",status])=1'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 2c9c2636aeb543ec8e70102c555fe776
              name: 'Controller [{#CONTROLLER.ID}]: IP address'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",ip_address]'
              value_type: CHAR
              description: 'Controller network port IP address.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''ip-address'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 3405ef21e2cb40729e16c5b8aaf35996
              name: 'Controller [{#CONTROLLER.ID}]: Part number'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",part_number]'
              value_type: CHAR
              description: 'Part number of the controller.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''part-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 9b4ee1a634c3462f8fb48eb0e79984df
              name: 'Controller [{#CONTROLLER.ID}]: Pools'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",pools]'
              description: 'Number of pools in the storage system.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-storage-pools'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: 6980d1841bc04c79868d6f05bf59921e
              name: 'Controller [{#CONTROLLER.ID}]: Serial number'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",serial_number]'
              value_type: CHAR
              description: 'Storage controller serial number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''serial-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: c0c2034fc848400c9b1f09f0c54790b3
              name: 'Controller [{#CONTROLLER.ID}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",status]'
              description: 'Storage controller status.'
              valuemap:
                name: 'Controller status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''status-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: component
                  value: health
                - tag: controller
                  value: '{#CONTROLLER.ID}'
              trigger_prototypes:
                - uuid: 99de4f8de416485db5c3844d1c8d654b
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",status])=1'
                  name: 'Controller [{#CONTROLLER.ID}]: Controller is down'
                  priority: HIGH
                  description: 'The controller is down.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 7a9b3ba8dd5446d0961a6eea595c2b49
              name: 'Controller [{#CONTROLLER.ID}]: Uptime'
              type: DEPENDENT
              key: 'hpe.msa.controllers["{#CONTROLLER.ID}",uptime]'
              units: uptime
              description: 'Number of seconds since the controller was restarted.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''power-on-time'']'
              master_item:
                key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              tags:
                - tag: component
                  value: controller
                - tag: controller
                  value: '{#CONTROLLER.ID}'
              trigger_prototypes:
                - uuid: 255250aa4b75465a989bf8f3fd805667
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.controllers["{#CONTROLLER.ID}",uptime])<10m'
                  name: 'Controller [{#CONTROLLER.ID}]: Controller has been restarted'
                  event_name: 'Controller [{#CONTROLLER.ID}]: Controller has been restarted (uptime < 10m)'
                  priority: WARNING
                  description: 'The controller uptime is less than 10 minutes.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: efd83949c23e4f8b8f137ca13bb2449c
              name: 'Controller [{#CONTROLLER.ID}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.controllers["{#CONTROLLER.ID}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered controller data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@[''durable-id''] == "{#DURABLE.ID}")].first()'
              master_item:
                key: hpe.msa.get.controllers
              tags:
                - tag: component
                  value: controller
                - tag: component
                  value: raw
                - tag: controller
                  value: '{#CONTROLLER.ID}'
            - uuid: d4be916f97ef415b9e892f464f8f8637
              name: 'Controller [{#CONTROLLER.ID}]: Get statistics data'
              type: DEPENDENT
              key: 'hpe.msa.get.controller_statistics["{#CONTROLLER.ID}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered controller statistics data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@[''durable-id''] == "{#DURABLE.ID}")].first()'
              master_item:
                key: hpe.msa.get.controller_statistics
              tags:
                - tag: component
                  value: controller
                - tag: component
                  value: raw
                - tag: controller
                  value: '{#CONTROLLER.ID}'
          graph_prototypes:
            - uuid: a0bac1256ecf42fb9e980a49e52f008e
              name: 'Controller [{#CONTROLLER.ID}]: Cache: Write utilization'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.cache.write["{#CONTROLLER.ID}",util]'
            - uuid: 2b3343a641304872a82c84e1b918f8b3
              name: 'Controller [{#CONTROLLER.ID}]: Cache usage'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.cache.read.hits["{#CONTROLLER.ID}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.cache.read.misses["{#CONTROLLER.ID}",rate]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.cache.write.hits["{#CONTROLLER.ID}",rate]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.cache.write.misses["{#CONTROLLER.ID}",rate]'
            - uuid: ed2117af47d94be9bed0632a0b662a25
              name: 'Controller [{#CONTROLLER.ID}]: Controller CPU utilization'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.cpu["{#CONTROLLER.ID}",util]'
            - uuid: 27b53c540cae45da9b2e13cbbb1ab821
              name: 'Controller [{#CONTROLLER.ID}]: Data transfer rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.data_transfer.reads["{#CONTROLLER.ID}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.data_transfer.writes["{#CONTROLLER.ID}",rate]'
            - uuid: ce3c794ac9424be5a104b812680cc77b
              name: 'Controller [{#CONTROLLER.ID}]: Disk operations rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.iops.read["{#CONTROLLER.ID}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.controllers.iops.write["{#CONTROLLER.ID}",rate]'
          master_item:
            key: hpe.msa.get.controllers
          lld_macro_paths:
            - lld_macro: '{#CONTROLLER.ID}'
              path: '$.[''controller-id'']'
            - lld_macro: '{#DURABLE.ID}'
              path: '$.[''durable-id'']'
        - uuid: 46478b42c76348d7824c715fd6d20f74
          name: 'Disks discovery'
          type: DEPENDENT
          key: hpe.msa.disks.discovery
          description: 'Discover disks.'
          item_prototypes:
            - uuid: 4fedb88c1bb74c2cb5a0f72fdfcff104
              name: 'Disk [{#DURABLE.ID}]: Blocks size'
              type: DEPENDENT
              key: 'hpe.msa.disks.blocks["{#DURABLE.ID}",size]'
              units: B
              description: 'The size of a block, in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocksize'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: a491cb03df9c4e3ead70e0a74d9337b2
              name: 'Disk [{#DURABLE.ID}]: Blocks total'
              type: DEPENDENT
              key: 'hpe.msa.disks.blocks["{#DURABLE.ID}",total]'
              description: 'Total space in blocks.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocks'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 6c20cf4e84b0427fbe797fc209d78785
              name: 'Disk [{#DURABLE.ID}]: Space total'
              type: CALCULATED
              key: 'hpe.msa.disks.space["{#DURABLE.ID}",total]'
              delay: 1h
              units: B
              params: 'last(//hpe.msa.disks.blocks["{#DURABLE.ID}",size])*last(//hpe.msa.disks.blocks["{#DURABLE.ID}",total])'
              description: 'Total size of the disk.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 80ea0929a1bf43f4bdeba80e675c52bd
              name: 'Disk [{#DURABLE.ID}]: SSD life left'
              type: DEPENDENT
              key: 'hpe.msa.disks.ssd["{#DURABLE.ID}",life_left]'
              discover: NO_DISCOVER
              units: '%'
              description: 'The percentage of disk life remaining.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''ssd-life-left-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: f5bb9b7f437f434d83ca0542e41b2673
              name: 'Disk [{#DURABLE.ID}]: Disk group'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",group]'
              value_type: CHAR
              description: 'If the disk is in a disk group, the disk group name.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''disk-group'']'
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 86fca5ad02af49c8a1d48f4a260a0dbf
              name: 'Disk [{#DURABLE.ID}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",health]'
              description: 'Disk health status.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: component
                  value: health
                - tag: disk
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: f76f8eec05a94e2db9d4cd3bcbb43aa4
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks["{#DURABLE.ID}",health])=1'
                  name: 'Disk [{#DURABLE.ID}]: Disk health is in degraded state'
                  priority: WARNING
                  description: 'Disk health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 383181e44a114334ab28ff09f49b2d51
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks["{#DURABLE.ID}",health])=2'
                  name: 'Disk [{#DURABLE.ID}]: Disk health is in fault state'
                  priority: AVERAGE
                  description: 'Disk health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 2b2d78c6c29f4bd58eff632809dee978
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks["{#DURABLE.ID}",health])=3'
                  name: 'Disk [{#DURABLE.ID}]: Disk health is in unknown state'
                  priority: INFO
                  description: 'Disk health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 8f8ad679881c4693acfed363e5498b34
              name: 'Disk [{#DURABLE.ID}]: Model'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",model]'
              value_type: CHAR
              description: 'Disk model.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''model'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 7fffecbf1ede4a5e9da5efc4311fc62e
              name: 'Disk [{#DURABLE.ID}]: Storage pool'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",pool]'
              value_type: CHAR
              description: 'If the disk is in a pool, the pool name.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''storage-pool-name'']'
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 9a43a148ad4742e1a1df0038b36a171f
              name: 'Disk [{#DURABLE.ID}]: Serial number'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",serial_number]'
              value_type: CHAR
              description: 'Disk serial number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''serial-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 119dc5c43fb741028ccd599d25ad032c
              name: 'Disk [{#DURABLE.ID}]: Temperature'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",temperature]'
              units: '!°C'
              description: 'Temperature of the disk.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''temperature-numeric'']'
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 0a0cf4600214443aa504d5c55d1f4015
              name: 'Disk [{#DURABLE.ID}]: Temperature status'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",temperature_status]'
              description: 'Disk temperature status.'
              valuemap:
                name: 'Disk temperature status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''temperature-status-numeric'']'
                  error_handler: DISCARD_VALUE
                - type: IN_RANGE
                  parameters:
                    - '1'
                    - '3'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: component
                  value: health
                - tag: disk
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: d4b8f77421d744918e087f696b3f0fff
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks["{#DURABLE.ID}",temperature_status])=2'
                  name: 'Disk [{#DURABLE.ID}]: Disk temperature is critically high'
                  priority: AVERAGE
                  description: 'Disk temperature is critically high.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: fbbac4048fda477a99f00566624b6bdb
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks["{#DURABLE.ID}",temperature_status])=3'
                  name: 'Disk [{#DURABLE.ID}]: Disk temperature is high'
                  priority: WARNING
                  description: 'Disk temperature is high.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 41e4f00446304206804da350a88ce3b9
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks["{#DURABLE.ID}",temperature_status])=4'
                  name: 'Disk [{#DURABLE.ID}]: Disk temperature is unknown'
                  priority: INFO
                  description: 'Disk temperature is unknown.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 1a23ef68bb484fd5baeba2b352b970db
              name: 'Disk [{#DURABLE.ID}]: Type'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",type]'
              description: |
                Disk type:
                SAS: Enterprise SAS spinning disk.
                SAS MDL: Midline SAS spinning disk.
                SSD SAS: SAS solit-state disk.
              valuemap:
                name: 'Disk type'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''description-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: d8e35779834640c8afdc5874f72fe8af
              name: 'Disk [{#DURABLE.ID}]: Vendor'
              type: DEPENDENT
              key: 'hpe.msa.disks["{#DURABLE.ID}",vendor]'
              value_type: CHAR
              description: 'Disk vendor.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''vendor'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: disk
                - tag: disk
                  value: '{#DURABLE.ID}'
            - uuid: 2f213e512833498081747c89b5238dc8
              name: 'Disk [{#DURABLE.ID}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.disks["{#DURABLE.ID}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered disk data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''durable-id''] == "{#DURABLE.ID}")].first()'
              master_item:
                key: hpe.msa.get.disks
              tags:
                - tag: component
                  value: disk
                - tag: component
                  value: raw
                - tag: disk
                  value: '{#DURABLE.ID}'
          master_item:
            key: hpe.msa.get.disks
          lld_macro_paths:
            - lld_macro: '{#DURABLE.ID}'
              path: '$.[''durable-id'']'
            - lld_macro: '{#TYPE}'
              path: '$.[''description-numeric'']'
          overrides:
            - name: 'SSD life left'
              step: '1'
              filter:
                conditions:
                  - macro: '{#TYPE}'
                    value: '8'
              operations:
                - operator: REGEXP
                  value: 'SSD life left'
                  discover: DISCOVER
        - uuid: 88aaea8c16a247559c68783ad0cd5c4d
          name: 'Disk groups discovery'
          type: DEPENDENT
          key: hpe.msa.disks.groups.discovery
          description: 'Discover disk groups.'
          item_prototypes:
            - uuid: 8f68ad1b814d4287a6fd72d5bd03f7da
              name: 'Disk group [{#NAME}]: Average response time: Read'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.avg_rsp_time["{#NAME}",read]'
              value_type: FLOAT
              units: s
              description: 'Average response time for all read operations, calculated over the interval since these statistics were last requested or reset.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''avg-read-rsp-time'']'
                - type: MULTIPLIER
                  parameters:
                    - '1.0E-6'
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 2ae8acbcd0b9442c9adc8086fa36fa40
              name: 'Disk group [{#NAME}]: Average response time: Total'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.avg_rsp_time["{#NAME}",total]'
              value_type: FLOAT
              units: s
              description: 'Average response time for read and write operations, calculated over the interval since these statistics were last requested or reset.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''avg-rsp-time'']'
                - type: MULTIPLIER
                  parameters:
                    - '1.0E-6'
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: f99ce5e6e31140c298ee447d3a2b8c4d
              name: 'Disk group [{#NAME}]: Average response time: Write'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.avg_rsp_time["{#NAME}",write]'
              value_type: FLOAT
              units: s
              description: 'Average response time for all write operations, calculated over the interval since these statistics were last requested or reset.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''avg-write-rsp-time'']'
                - type: MULTIPLIER
                  parameters:
                    - '1.0E-6'
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 705fce660a944a47ad7ff0e9c9b1d37e
              name: 'Disk group [{#NAME}]: Blocks free'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.blocks["{#NAME}",free]'
              description: 'Free space in blocks.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''freespace-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 27e3fc79212e407ca1ae5fb06557440d
              name: 'Disk group [{#NAME}]: Blocks size'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.blocks["{#NAME}",size]'
              units: B
              description: 'The size of a block, in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocksize'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: f14e651fd9dc4b03bb00e5db780f0114
              name: 'Disk group [{#NAME}]: Blocks total'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.blocks["{#NAME}",total]'
              description: 'Total space in blocks.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocks'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: ecd3de6d32e94d2ab50111659147c97e
              name: 'Disk group [{#NAME}]: Data transfer rate: Reads'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.data_transfer.reads["{#NAME}",rate]'
              value_type: FLOAT
              units: Bps
              description: 'The data read rate, in bytes per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''data-read-numeric'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 28b236ea619f4130a3271459e9fce06b
              name: 'Disk group [{#NAME}]: Data transfer rate: Total'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.data_transfer.total["{#NAME}",rate]'
              units: Bps
              description: 'The data transfer rate, in bytes per second, calculated over the interval since these statistics were last requested or reset. This value will be zero if it has not been requested or reset since a controller restart.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''bytes-per-second-numeric'']'
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 51ef802067c149bea1d5d976df6e3a6f
              name: 'Disk group [{#NAME}]: Data transfer rate: Writes'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.data_transfer.writes["{#NAME}",rate]'
              value_type: FLOAT
              units: Bps
              description: 'The data write rate, in bytes per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''data-written-numeric'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 95925d6d4af94964b388208ff185642d
              name: 'Disk group [{#NAME}]: IOPS, read rate'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.iops.read["{#NAME}",rate]'
              value_type: FLOAT
              units: '!r/s'
              description: 'Number of read operations per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-reads'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: c9fdf59576554063b404d190ad90db18
              name: 'Disk group [{#NAME}]: IOPS, total rate'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.iops.total["{#NAME}",rate]'
              units: '!iops'
              description: 'Input/output operations per second, calculated over the interval since these statistics were last requested or reset. This value will be zero if it has not been requested or reset since a controller restart.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''iops'']'
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 31f5b13a56704e438b600df70c37a1fd
              name: 'Disk group [{#NAME}]: IOPS, write rate'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.iops.write["{#NAME}",rate]'
              value_type: FLOAT
              units: '!w/s'
              description: 'Number of write operations per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-writes'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 7359b1d550734d30bb83612538b36e95
              name: 'Disk group [{#NAME}]: RAID type'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.raid["{#NAME}",type]'
              description: 'The RAID level of the disk group.'
              valuemap:
                name: 'RAID type'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''raidtype-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: b0d49d3da6b14b9cb8eeb95a3665a26e
              name: 'Disk group [{#NAME}]: Space free'
              type: CALCULATED
              key: 'hpe.msa.disks.groups.space["{#NAME}",free]'
              units: B
              params: 'last(//hpe.msa.disks.groups.blocks["{#NAME}",size])*last(//hpe.msa.disks.groups.blocks["{#NAME}",free])'
              description: 'The free space in the disk group.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: bc8e6e0fb286466593186708cddf3b2a
              name: 'Disk group [{#NAME}]: Pool space used'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups.space["{#NAME}",pool_util]'
              units: '%'
              description: 'The percentage of pool capacity that the disk group occupies.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''pool-percentage'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: fb3dd5308c97446693932206be17ace3
              name: 'Disk group [{#NAME}]: Space total'
              type: CALCULATED
              key: 'hpe.msa.disks.groups.space["{#NAME}",total]'
              units: B
              params: 'last(//hpe.msa.disks.groups.blocks["{#NAME}",size])*last(//hpe.msa.disks.groups.blocks["{#NAME}",total])'
              description: 'The capacity of the disk group.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 2a9c7f901f494b8bb7d2c74cd7c3030c
              name: 'Disk group [{#NAME}]: Space utilization'
              type: CALCULATED
              key: 'hpe.msa.disks.groups.space["{#NAME}",util]'
              value_type: FLOAT
              units: '%'
              params: '100-last(//hpe.msa.disks.groups.space["{#NAME}",free])/last(//hpe.msa.disks.groups.space["{#NAME}",total])*100'
              description: 'The space utilization percentage in the disk group.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: df1af9dad6444821a86a26158469d0cb
                  expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups.space["{#NAME}",util],5m)>{$HPE.MSA.DISKS.GROUP.PUSED.MAX.CRIT:"{#NAME}"}'
                  name: 'Disk group [{#NAME}]: Disk group space is critically low'
                  event_name: 'Disk group [{#NAME}]: Disk group space is critically low (used > {$HPE.MSA.DISKS.GROUP.PUSED.MAX.CRIT:"{#NAME}"}%)'
                  priority: AVERAGE
                  description: 'Disk group is running low on free space (less than {$HPE.MSA.DISKS.GROUP.PUSED.MAX.CRIT:"{#NAME}"}% available).'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 713960711c324dc780998f8f263344a2
                  expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups.space["{#NAME}",util],5m)>{$HPE.MSA.DISKS.GROUP.PUSED.MAX.WARN:"{#NAME}"}'
                  name: 'Disk group [{#NAME}]: Disk group space is low'
                  event_name: 'Disk group [{#NAME}]: Disk group space is low (used > {$HPE.MSA.DISKS.GROUP.PUSED.MAX.WARN:"{#NAME}"}%)'
                  priority: WARNING
                  description: 'Disk group is running low on free space (less than {$HPE.MSA.DISKS.GROUP.PUSED.MAX.WARN:"{#NAME}"}% available).'
                  dependencies:
                    - name: 'Disk group [{#NAME}]: Disk group space is critically low'
                      expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups.space["{#NAME}",util],5m)>{$HPE.MSA.DISKS.GROUP.PUSED.MAX.CRIT:"{#NAME}"}'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 4c6bbdcdb05d45e0af52548aef4e8716
              name: 'Disk group [{#NAME}]: Disks count'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups["{#NAME}",disk_count]'
              description: 'Number of disks in the disk group.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''diskcount'']'
                  error_handler: DISCARD_VALUE
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 97b6e0e2ec844636be64931fca6e2c6c
              name: 'Disk group [{#NAME}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups["{#NAME}",health]'
              description: 'Disk group health.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: component
                  value: health
                - tag: disk-group
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 7899b8a15b5042f3a4467a7cdee4c6ae
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",health])=1'
                  name: 'Disk group [{#NAME}]: Disk group health is in degraded state'
                  priority: WARNING
                  description: 'Disk group health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: e7c6a3b20c424196854a5437aba4c3ec
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",health])=2'
                  name: 'Disk group [{#NAME}]: Disk group health is in fault state'
                  priority: AVERAGE
                  description: 'Disk group health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 177dd9d1cfa54b3e8c9e6479cb96af03
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",health])=3'
                  name: 'Disk group [{#NAME}]: Disk group health is in unknown state'
                  priority: INFO
                  description: 'Disk group health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: 6755c1253e83442780eeb31d67062980
              name: 'Disk group [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.disks.groups["{#NAME}",status]'
              description: |
                The status of the disk group:
                
                - CRIT: Critical. The disk group is online but isn't fault tolerant because some of it's disks are down.
                - DMGD: Damaged. The disk group is online and fault tolerant, but some of it's disks are damaged.
                - FTDN: Fault tolerant with a down disk.The disk group is online and fault tolerant, but some of it's disks are down.
                - FTOL: Fault tolerant.
                - MSNG: Missing. The disk group is online and fault tolerant, but some of it's disks are missing.
                - OFFL: Offline. Either the disk group is using offline initialization, or it's disks are down and data may be lost.
                - QTCR: Quarantined critical. The disk group is critical with at least one inaccessible disk. For example, two disks are inaccessible in a RAID 6 disk group or one disk is inaccessible for other fault-tolerant RAID levels. If the inaccessible disks come online or if after 60 seconds from being quarantined the disk group is QTCRor QTDN, the disk group is automatically dequarantined.
                - QTDN: Quarantined with a down disk. The RAID6 disk group has one inaccessible disk. The disk group is fault tolerant but degraded. If the inaccessible disks come online or if after 60 seconds from being quarantined the disk group is QTCRor QTDN, the disk group is automatically dequarantined.
                - QTOF: Quarantined offline. The disk group is offline with multiple inaccessible disks causing user data to be incomplete, or is an NRAID or RAID 0 disk group.
                - QTUN: Quarantined unsupported. The disk group contains data in a format that is not supported by this system. For example, this system does not support linear disk groups.
                - STOP: The disk group is stopped.
                - UNKN: Unknown.
                - UP: Up. The disk group is online and does not have fault-tolerant attributes.
              valuemap:
                name: 'Disk group status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''status-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              tags:
                - tag: component
                  value: disk-group
                - tag: component
                  value: health
                - tag: disk-group
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 8deee88d964846598d5574d197694b17
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=9'
                  name: 'Disk group [{#NAME}]: Disk group has damaged disks'
                  priority: AVERAGE
                  description: 'The disk group is online and fault tolerant, but some of it''s disks are damaged.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: c615e1bb1c824e7ba109b8a6580eb9b9
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=8'
                  name: 'Disk group [{#NAME}]: Disk group has missing disks'
                  priority: AVERAGE
                  description: 'The disk group is online and fault tolerant, but some of it''s disks are missing.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: bead3a0bb95342b3b3ceae7becff99b8
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=1'
                  name: 'Disk group [{#NAME}]: Disk group is fault tolerant with a down disk'
                  priority: AVERAGE
                  description: 'The disk group is online and fault tolerant, but some of it''s disks are down.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: c89466e00c2b40c1933fde60332a428a
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=3'
                  name: 'Disk group [{#NAME}]: Disk group is offline'
                  priority: AVERAGE
                  description: 'Either the disk group is using offline initialization, or it''s disks are down and data may be lost.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 3dc5b3bc1128451491217639cf4e5115
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=4'
                  name: 'Disk group [{#NAME}]: Disk group is quarantined critical'
                  priority: AVERAGE
                  description: 'The disk group is critical with at least one inaccessible disk. For example, two disks are inaccessible in a RAID 6 disk group or one disk is inaccessible for other fault-tolerant RAID levels. If the inaccessible disks come online or if after 60 seconds from being quarantined the disk group is QTCRor QTDN, the disk group is automatically dequarantined.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 6892c8c05331497ab37db2b2fe3673a1
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=5'
                  name: 'Disk group [{#NAME}]: Disk group is quarantined offline'
                  priority: AVERAGE
                  description: 'The disk group is offline with multiple inaccessible disks causing user data to be incomplete, or is an NRAID or RAID 0 disk group.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 8a8bda977e11462a906fd200f1b67a72
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=5'
                  name: 'Disk group [{#NAME}]: Disk group is quarantined unsupported'
                  priority: AVERAGE
                  description: 'The disk group contains data in a format that is not supported by this system. For example, this system does not support linear disk groups.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 21f06dd8f8de49f58a64a638d24ff905
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=6'
                  name: 'Disk group [{#NAME}]: Disk group is quarantined with an inaccessible disk'
                  priority: AVERAGE
                  description: 'The RAID6 disk group has one inaccessible disk. The disk group is fault tolerant but degraded. If the inaccessible disks come online or if after 60 seconds from being quarantined the disk group is QTCRor QTDN, the disk group is automatically dequarantined.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 1914fede726744829b2e41392b957857
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=7'
                  name: 'Disk group [{#NAME}]: Disk group is stopped'
                  priority: AVERAGE
                  description: 'The disk group is stopped.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: a79a6cf86bd44f55a7859808f632bf48
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.disks.groups["{#NAME}",status])=2'
                  name: 'Disk group [{#NAME}]: Disk group status is critical'
                  priority: AVERAGE
                  description: 'The disk group is online but isn''t fault tolerant because some of its disks are down.'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 7c7ce5cd807a4791800ed5f812b4b633
              name: 'Disk group [{#NAME}]: Get statistics data'
              type: DEPENDENT
              key: 'hpe.msa.get.disks.groups.statistics["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered disk group statistics data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@[''name''] == "{#NAME}")].first()'
              master_item:
                key: hpe.msa.disks.get.groups.statistics
              tags:
                - tag: component
                  value: disk-group
                - tag: component
                  value: raw
                - tag: disk-group
                  value: '{#NAME}'
            - uuid: 9520e31d713b4ba59b682f47dda7154e
              name: 'Disk group [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.disks.groups["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered disk group data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@[''name''] == "{#NAME}")].first()'
              master_item:
                key: hpe.msa.get.disks.groups
              tags:
                - tag: component
                  value: disk-group
                - tag: component
                  value: raw
                - tag: disk-group
                  value: '{#NAME}'
          graph_prototypes:
            - uuid: e1f7331965524670b8c44c0b0d8eb99b
              name: 'Disk group [{#NAME}]: Average response time'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.avg_rsp_time["{#NAME}",read]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.avg_rsp_time["{#NAME}",write]'
            - uuid: 1354b947316a46be8dc696c29f408a6b
              name: 'Disk group [{#NAME}]: Data transfer rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.data_transfer.reads["{#NAME}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.data_transfer.writes["{#NAME}",rate]'
            - uuid: f7f556011add4cd6b0fe8e4545c607a0
              name: 'Disk group [{#NAME}]: Disk operations rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.iops.read["{#NAME}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.iops.write["{#NAME}",rate]'
            - uuid: 495a941dc4ef45e8b60d6a94bb1fbdcd
              name: 'Disk group [{#NAME}]: Space utilization'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.space["{#NAME}",free]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.disks.groups.space["{#NAME}",total]'
          master_item:
            key: hpe.msa.get.disks.groups
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: '$.[''name'']'
        - uuid: 5a97871f702348dca7a5378885087ea8
          name: 'Enclosures discovery'
          type: DEPENDENT
          key: hpe.msa.enclosures.discovery
          description: 'Discover enclosures.'
          item_prototypes:
            - uuid: 2e70432b3c324ecdb78ab77e5f9bbaf3
              name: 'Enclosure [{#DURABLE.ID}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.enclosures["{#DURABLE.ID}",health]'
              description: 'Enclosure health.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: health
                - tag: enclosure
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: d15d460b8c924f609f5cdd055060f8ce
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",health])=1'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure health is in degraded state'
                  priority: WARNING
                  description: 'Enclosure health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 7c2f6a7efbf245298c3ee0b137718dc8
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",health])=2'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure health is in fault state'
                  priority: AVERAGE
                  description: 'Enclosure health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6732ced099d748daa5cbdf6d97580efd
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",health])=3'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure health is in unknown state'
                  priority: INFO
                  description: 'Enclosure health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: e3a1c5f6dee545a8a7d4b68768d060ab
              name: 'Enclosure [{#DURABLE.ID}]: Midplane serial number'
              type: DEPENDENT
              key: 'hpe.msa.enclosures["{#DURABLE.ID}",midplane_serial_number]'
              value_type: CHAR
              description: 'Midplane serial number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''midplane-serial-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#DURABLE.ID}'
            - uuid: 1dcecf03b9814aac9749badf800e4717
              name: 'Enclosure [{#DURABLE.ID}]: Model'
              type: DEPENDENT
              key: 'hpe.msa.enclosures["{#DURABLE.ID}",model]'
              value_type: CHAR
              description: 'Enclosure model.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''model'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#DURABLE.ID}'
            - uuid: 89f11d7bf0e24a92bf4d4b4b1d86af58
              name: 'Enclosure [{#DURABLE.ID}]: Part number'
              type: DEPENDENT
              key: 'hpe.msa.enclosures["{#DURABLE.ID}",part_number]'
              value_type: CHAR
              description: 'Enclosure part number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''part-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#DURABLE.ID}'
            - uuid: b426baf09f1445eda59abd0e2ee6dd2c
              name: 'Enclosure [{#DURABLE.ID}]: Power'
              type: DEPENDENT
              key: 'hpe.msa.enclosures["{#DURABLE.ID}",power]'
              value_type: FLOAT
              units: W
              description: 'Enclosure power in watts.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''enclosure-power'']'
              master_item:
                key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: enclosure
                  value: '{#DURABLE.ID}'
            - uuid: 602b941548ab417bbe59f3f298bf6da9
              name: 'Enclosure [{#DURABLE.ID}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.enclosures["{#DURABLE.ID}",status]'
              description: 'Enclosure status.'
              valuemap:
                name: 'Enclosure status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''status-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '6'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: health
                - tag: enclosure
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: ef763c350b2e4d20bdecbe50703ec8dd
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",status])=2'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure has critical status'
                  priority: HIGH
                  description: 'Enclosure has critical status.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: e3a7198f287e4600a0abfa929ee183de
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",status])=6'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure has unknown status'
                  priority: INFO
                  description: 'Enclosure has unknown status.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: 27ba4d2474604caaa2712222cf621294
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",status])=3'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure has warning status'
                  priority: WARNING
                  description: 'Enclosure has warning status.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 53b61c7521d94161b063a5ea506b5466
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",status])=7'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure is unavailable'
                  priority: HIGH
                  description: 'Enclosure is unavailable.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 2218d1bf55aa4db0968dab804c0687e3
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.enclosures["{#DURABLE.ID}",status])=4'
                  name: 'Enclosure [{#DURABLE.ID}]: Enclosure is unrecoverable'
                  priority: HIGH
                  description: 'Enclosure is unrecoverable.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: f9d69bb1597e435f8c8c67b51998c0a4
              name: 'Enclosure [{#DURABLE.ID}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.enclosures["{#DURABLE.ID}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered enclosure data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''durable-id''] == "{#DURABLE.ID}")].first()'
              master_item:
                key: hpe.msa.get.enclosures
              tags:
                - tag: component
                  value: enclosure
                - tag: component
                  value: raw
                - tag: enclosure
                  value: '{#DURABLE.ID}'
          master_item:
            key: hpe.msa.get.enclosures
          lld_macro_paths:
            - lld_macro: '{#DURABLE.ID}'
              path: '$.[''durable-id'']'
        - uuid: 9043169f17de44baa174459b560de4f5
          name: 'Fans discovery'
          type: DEPENDENT
          key: hpe.msa.fans.discovery
          description: 'Discover fans.'
          item_prototypes:
            - uuid: f9be9af4ff9047f1af946313df3e7165
              name: 'Fan [{#DURABLE.ID}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.fans["{#DURABLE.ID}",health]'
              description: 'Fan health status.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.fans["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: fan
                - tag: component
                  value: health
                - tag: fan
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: 3ee1b1d0d6b34c8eba02480e9e4d5be2
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.fans["{#DURABLE.ID}",health])=1'
                  name: 'Fan [{#DURABLE.ID}]: Fan health is in degraded state'
                  priority: WARNING
                  description: 'Fan health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 3e3785f9915d46068ebe2eff21bac813
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.fans["{#DURABLE.ID}",health])=2'
                  name: 'Fan [{#DURABLE.ID}]: Fan health is in fault state'
                  priority: AVERAGE
                  description: 'Fan health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 4bf2e519b5484d338f997ea5dac462e0
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.fans["{#DURABLE.ID}",health])=3'
                  name: 'Fan [{#DURABLE.ID}]: Fan health is in unknown state'
                  priority: INFO
                  description: 'Fan health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: f028a919d56b45129f9ead200519adaa
              name: 'Fan [{#DURABLE.ID}]: Speed'
              type: DEPENDENT
              key: 'hpe.msa.fans["{#DURABLE.ID}",speed]'
              units: '!RPM'
              description: 'Fan speed (revolutions per minute).'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''speed'']'
              master_item:
                key: 'hpe.msa.get.fans["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: fan
                - tag: fan
                  value: '{#DURABLE.ID}'
            - uuid: df1d8af5df104afc829b403aec6efc96
              name: 'Fan [{#DURABLE.ID}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.fans["{#DURABLE.ID}",status]'
              description: 'Fan status.'
              valuemap:
                name: 'Fan status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''status-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.fans["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: fan
                - tag: component
                  value: health
                - tag: fan
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: 183a1e1c4d444c9a8189035a2af22dc1
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.fans["{#DURABLE.ID}",status])=1'
                  name: 'Fan [{#DURABLE.ID}]: Fan has error status'
                  priority: AVERAGE
                  description: 'Fan has error status.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 4d9e3d1bb22444f981295df07f0d9c24
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.fans["{#DURABLE.ID}",status])=3'
                  name: 'Fan [{#DURABLE.ID}]: Fan is missing'
                  priority: INFO
                  description: 'Fan is missing.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: a6e4ea796b98432284a9fd9fff1d82f9
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.fans["{#DURABLE.ID}",status])=2'
                  name: 'Fan [{#DURABLE.ID}]: Fan is off'
                  priority: WARNING
                  description: 'Fan is off.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 468505cb7da74e04966477b02ab63b12
              name: 'Fan [{#DURABLE.ID}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.fans["{#DURABLE.ID}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered fan data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''durable-id''] == "{#DURABLE.ID}")].first()'
              master_item:
                key: hpe.msa.get.fans
              tags:
                - tag: component
                  value: fan
                - tag: component
                  value: raw
                - tag: fan
                  value: '{#DURABLE.ID}'
          graph_prototypes:
            - uuid: 1def9fd4627d4552bf34e8ce35f3cd46
              name: 'Fan [{#DURABLE.ID}]: Speed'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.fans["{#DURABLE.ID}",speed]'
          master_item:
            key: hpe.msa.get.fans
          lld_macro_paths:
            - lld_macro: '{#DURABLE.ID}'
              path: '$.[''durable-id'']'
        - uuid: 30f91e8f7fba489aa649759219efa67c
          name: 'FRU discovery'
          type: DEPENDENT
          key: hpe.msa.frus.discovery
          filter:
            conditions:
              - macro: '{#TYPE}'
                value: ^(POWER_SUPPLY|RAID_IOM|CHASSIS_MIDPLANE)$
                operator: NOT_MATCHES_REGEX
          description: 'Discover FRU.'
          item_prototypes:
            - uuid: 8cbf62d188084ea4a72eaa37987d8d8e
              name: 'FRU [{#ENCLOSURE.ID}: {#LOCATION}]: Part number'
              type: DEPENDENT
              key: 'hpe.msa.frus["{#ENCLOSURE.ID}:{#LOCATION}",part_number]'
              value_type: CHAR
              description: '{#DESCRIPTION}. Part number of the FRU.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''part-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.frus["{#ENCLOSURE.ID}:{#LOCATION}",data]'
              tags:
                - tag: component
                  value: fru
                - tag: fru
                  value: 'Enclosure {#ENCLOSURE.ID}: {#LOCATION}'
            - uuid: 49c52c2c5b174c78a60756eb7a9e34f1
              name: 'FRU [{#ENCLOSURE.ID}: {#LOCATION}]: Serial number'
              type: DEPENDENT
              key: 'hpe.msa.frus["{#ENCLOSURE.ID}:{#LOCATION}",serial_number]'
              value_type: CHAR
              description: '{#DESCRIPTION}. FRU serial number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''serial-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.frus["{#ENCLOSURE.ID}:{#LOCATION}",data]'
              tags:
                - tag: component
                  value: fru
                - tag: fru
                  value: 'Enclosure {#ENCLOSURE.ID}: {#LOCATION}'
            - uuid: d72f7be111ae4335b92d6a1d0ad9e3ee
              name: 'FRU [{#ENCLOSURE.ID}: {#LOCATION}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.frus["{#ENCLOSURE.ID}:{#LOCATION}",status]'
              description: |
                {#DESCRIPTION}. FRU status:
                
                Absent: The FRU is not present.
                Fault: The FRU's health is Degraded or Fault.
                Invalid data: The FRU ID data is invalid. The FRU's EEPROM is improperly programmed.
                OK: The FRU is operating normally.
                Power off: The FRU is powered off.
              valuemap:
                name: 'FRU status'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''fru-status-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.frus["{#ENCLOSURE.ID}:{#LOCATION}",data]'
              tags:
                - tag: component
                  value: fru
                - tag: component
                  value: health
                - tag: fru
                  value: 'Enclosure {#ENCLOSURE.ID}: {#LOCATION}'
              trigger_prototypes:
                - uuid: 2533eb2e4344494d9ec72629dab7b1a8
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.frus["{#ENCLOSURE.ID}:{#LOCATION}",status])=0'
                  name: 'FRU [{#ENCLOSURE.ID}: {#LOCATION}]: FRU ID data is invalid'
                  priority: WARNING
                  description: 'The FRU ID data is invalid. The FRU''s EEPROM is improperly programmed.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 7a994469e45f467c8582c24258d0eb75
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.frus["{#ENCLOSURE.ID}:{#LOCATION}",status])=1'
                  name: 'FRU [{#ENCLOSURE.ID}: {#LOCATION}]: FRU status is Degraded or Fault'
                  priority: AVERAGE
                  description: 'FRU status is Degraded or Fault.'
                  tags:
                    - tag: scope
                      value: availability
            - uuid: 7bf42c023d5647bdbc4c35d0fb474454
              name: 'FRU [{#ENCLOSURE.ID}: {#LOCATION}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.frus["{#ENCLOSURE.ID}:{#LOCATION}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered FRU data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''name''] == "{#TYPE}")].first()'
              master_item:
                key: hpe.msa.get.fru
              tags:
                - tag: component
                  value: fru
                - tag: component
                  value: raw
                - tag: fru
                  value: 'Enclosure {#ENCLOSURE.ID}: {#LOCATION}'
          master_item:
            key: hpe.msa.get.fru
          lld_macro_paths:
            - lld_macro: '{#DESCRIPTION}'
              path: '$.[''description'']'
            - lld_macro: '{#ENCLOSURE.ID}'
              path: '$.[''enclosure-id'']'
            - lld_macro: '{#LOCATION}'
              path: '$.[''fru-location'']'
            - lld_macro: '{#TYPE}'
              path: '$.[''name'']'
        - uuid: 178b94ddcab947ffb1614622c2b7e08e
          name: 'Pools discovery'
          type: DEPENDENT
          key: hpe.msa.pools.discovery
          description: 'Discover pools.'
          item_prototypes:
            - uuid: 677f29f2879c44ceaf210bed98f257b0
              name: 'Pool [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.pools["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered pool data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''name''] == "{#NAME}")].first()'
              master_item:
                key: hpe.msa.get.pools
              tags:
                - tag: component
                  value: pool
                - tag: component
                  value: raw
                - tag: pool
                  value: '{#NAME}'
            - uuid: 09d67b3577af4e21a7bbd09078d705cd
              name: 'Pool [{#NAME}]: Blocks available'
              type: DEPENDENT
              key: 'hpe.msa.pools.blocks["{#NAME}",available]'
              description: 'Available space in blocks.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''total-avail-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
            - uuid: 076921fcd93941b09b79c7d44873417d
              name: 'Pool [{#NAME}]: Blocks size'
              type: DEPENDENT
              key: 'hpe.msa.pools.blocks["{#NAME}",size]'
              units: B
              description: 'The size of a block, in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocksize'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
            - uuid: fd29559e5bb3455b8b4cfe56f75f54b2
              name: 'Pool [{#NAME}]: Blocks total'
              type: DEPENDENT
              key: 'hpe.msa.pools.blocks["{#NAME}",total]'
              description: 'Total space in blocks.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''total-size-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
            - uuid: d99eeba76b354e73b0118b46402d93bf
              name: 'Pool [{#NAME}]: Space free'
              type: CALCULATED
              key: 'hpe.msa.pools.space["{#NAME}",free]'
              units: B
              params: 'last(//hpe.msa.pools.blocks["{#NAME}",size])*last(//hpe.msa.pools.blocks["{#NAME}",available])'
              description: 'The free space in the pool.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
            - uuid: 9fce545fbe724da28a13b8ca8759c37d
              name: 'Pool [{#NAME}]: Space total'
              type: CALCULATED
              key: 'hpe.msa.pools.space["{#NAME}",total]'
              units: B
              params: 'last(//hpe.msa.pools.blocks["{#NAME}",size])*last(//hpe.msa.pools.blocks["{#NAME}",total])'
              description: 'The capacity of the pool.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
            - uuid: ad9bdb342a494d82a36e42e75a3bbf3e
              name: 'Pool [{#NAME}]: Space utilization'
              type: CALCULATED
              key: 'hpe.msa.pools.space["{#NAME}",util]'
              value_type: FLOAT
              units: '%'
              params: '100-last(//hpe.msa.pools.space["{#NAME}",free])/last(//hpe.msa.pools.space["{#NAME}",total])*100'
              description: 'The space utilization percentage in the pool.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: c73b4a77e94a43f5951f6a541d65637e
                  expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.pools.space["{#NAME}",util],5m)>{$HPE.MSA.POOL.PUSED.MAX.CRIT:"{#NAME}"}'
                  name: 'Pool [{#NAME}]: Pool space is critically low'
                  event_name: 'Pool [{#NAME}]: Pool space is critically low (used > {$HPE.MSA.POOL.PUSED.MAX.CRIT:"{#NAME}"}%)'
                  priority: AVERAGE
                  description: 'Pool is running low on free space (less than {$HPE.MSA.POOL.PUSED.MAX.CRIT:"{#NAME}"}% available).'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: c7644beb62bc40e99d6045af6d4bc16f
                  expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.pools.space["{#NAME}",util],5m)>{$HPE.MSA.POOL.PUSED.MAX.WARN:"{#NAME}"}'
                  name: 'Pool [{#NAME}]: Pool space is low'
                  event_name: 'Pool [{#NAME}]: Pool space is low (used > {$HPE.MSA.POOL.PUSED.MAX.WARN:"{#NAME}"}%)'
                  priority: WARNING
                  description: 'Pool is running low on free space (less than {$HPE.MSA.POOL.PUSED.MAX.WARN:"{#NAME}"}% available).'
                  dependencies:
                    - name: 'Pool [{#NAME}]: Pool space is critically low'
                      expression: 'min(/HPE MSA 2060 Storage by HTTP/hpe.msa.pools.space["{#NAME}",util],5m)>{$HPE.MSA.POOL.PUSED.MAX.CRIT:"{#NAME}"}'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 15096639cae947d383a506f0332ff6d3
              name: 'Pool [{#NAME}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.pools["{#NAME}",health]'
              description: 'Pool health.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.pools["{#NAME}",data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: pool
                - tag: pool
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 20723e93add44447a5cab3c8cc4849a6
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.pools["{#NAME}",health])=1'
                  name: 'Pool [{#NAME}]: Pool health is in degraded state'
                  priority: WARNING
                  description: 'Pool health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 1881bd0efca04c58a56effb8e232e734
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.pools["{#NAME}",health])=2'
                  name: 'Pool [{#NAME}]: Pool health is in fault state'
                  priority: AVERAGE
                  description: 'Pool health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 62db05047b5a4b8797eee5667bb3bdf4
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.pools["{#NAME}",health])=3'
                  name: 'Pool [{#NAME}]: Pool health is in unknown state'
                  priority: INFO
                  description: 'Pool [{#NAME}] health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
          graph_prototypes:
            - uuid: 93151c5760fb405498d1df049185ffe7
              name: 'Pool [{#NAME}]: Space utilization'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.pools.space["{#NAME}",free]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.pools.space["{#NAME}",total]'
          master_item:
            key: hpe.msa.get.pools
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: '$.[''name'']'
        - uuid: bed52618dbc6498f99ddeedc78c0cdad
          name: 'Ports discovery'
          type: DEPENDENT
          key: hpe.msa.ports.discovery
          description: 'Discover ports.'
          item_prototypes:
            - uuid: 540799973d2d440ca80eeeae99f84798
              name: 'Port [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.ports["{#NAME}",,data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered port data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''port''] == "{#NAME}")].first()'
              master_item:
                key: hpe.msa.get.ports
              tags:
                - tag: component
                  value: port
                - tag: component
                  value: raw
                - tag: port
                  value: '{#NAME}'
            - uuid: cf4f9aaf55e6435d949d3b5074b9f37f
              name: 'Port [{#NAME}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.ports["{#NAME}",health]'
              description: 'Port health status.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.ports["{#NAME}",,data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: port
                - tag: port
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 9775011d59a846669087e6c90c4a011a
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.ports["{#NAME}",health])=1'
                  name: 'Port [{#NAME}]: Port health is in degraded state'
                  priority: WARNING
                  description: 'Port health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: a5dec537528f42e0948ea15f1a290f26
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.ports["{#NAME}",health])=2'
                  name: 'Port [{#NAME}]: Port health is in fault state'
                  priority: AVERAGE
                  description: 'Port health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 7025a0e6c93e4731be966c2a9e774581
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.ports["{#NAME}",health])=3'
                  name: 'Port [{#NAME}]: Port health is in unknown state'
                  priority: INFO
                  description: 'Port health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: cab1cd26264d408998c5ea8737571ed4
              name: 'Port [{#NAME}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.ports["{#NAME}",status]'
              description: 'Port status.'
              valuemap:
                name: Status
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''status-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.ports["{#NAME}",,data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: port
                - tag: port
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: c1d2f824a3d4470abb6817753b1d4047
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.ports["{#NAME}",status])=2'
                  name: 'Port [{#NAME}]: Port has error status'
                  priority: AVERAGE
                  description: 'Port has error status.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 6083cdfcb59848a6b5249147155996c2
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.ports["{#NAME}",status])=4'
                  name: 'Port [{#NAME}]: Port has unknown status'
                  priority: INFO
                  description: 'Port has unknown status.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: dd32b960ce1544d880d94b2da4dba03e
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.ports["{#NAME}",status])=1'
                  name: 'Port [{#NAME}]: Port has warning status'
                  priority: WARNING
                  description: 'Port has warning status.'
                  tags:
                    - tag: scope
                      value: performance
            - uuid: 32ad6655625e408a9dd577624afbfa6a
              name: 'Port [{#NAME}]: Type'
              type: DEPENDENT
              key: 'hpe.msa.ports["{#NAME}",type]'
              description: 'Port type.'
              valuemap:
                name: 'Port type'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''port-type-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.ports["{#NAME}",,data]'
              tags:
                - tag: component
                  value: port
                - tag: port
                  value: '{#NAME}'
          master_item:
            key: hpe.msa.get.ports
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: '$.[''port'']'
        - uuid: 1561695bd2174eada622a0d90ee1c3df
          name: 'Power supplies discovery'
          type: DEPENDENT
          key: hpe.msa.power_supplies.discovery
          description: 'Discover power supplies.'
          item_prototypes:
            - uuid: b7f37328cfff49789216d9caec2d09bc
              name: 'Power supply [{#DURABLE.ID}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.power_supplies["{#DURABLE.ID}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered power supply data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$[?(@[''durable-id''] == "{#DURABLE.ID}")].first()'
              master_item:
                key: hpe.msa.get.power_supplies
              tags:
                - tag: component
                  value: power-supply
                - tag: component
                  value: raw
                - tag: power-supply
                  value: '{#DURABLE.ID}'
            - uuid: 993bc2db3b444dc5bc37794985e63ea9
              name: 'Power supply [{#DURABLE.ID}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.power_supplies["{#DURABLE.ID}",health]'
              description: 'Power supply health status.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.power_supplies["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: power-supply
                - tag: power-supply
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: 1b512fda735440b5839a63fd26c19535
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.power_supplies["{#DURABLE.ID}",health])=1'
                  name: 'Power supply [{#DURABLE.ID}]: Power supply health is in degraded state'
                  priority: WARNING
                  description: 'Power supply health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: b75fb541ae0e43cc9cdb86e07dc3e394
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.power_supplies["{#DURABLE.ID}",health])=2'
                  name: 'Power supply [{#DURABLE.ID}]: Power supply health is in fault state'
                  priority: AVERAGE
                  description: 'Power supply health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: 555ee9ef33b54d029df2f17d5f899539
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.power_supplies["{#DURABLE.ID}",health])=3'
                  name: 'Power supply [{#DURABLE.ID}]: Power supply health is in unknown state'
                  priority: INFO
                  description: 'Power supply health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
            - uuid: efae55cfdd1e4021a623e2128f988611
              name: 'Power supply [{#DURABLE.ID}]: Part number'
              type: DEPENDENT
              key: 'hpe.msa.power_supplies["{#DURABLE.ID}",part_number]'
              value_type: CHAR
              description: 'Power supply part number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''part-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.power_supplies["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: power-supply
                - tag: power-supply
                  value: '{#DURABLE.ID}'
            - uuid: 6716c3d0177247fe8a35fa1eb206a54f
              name: 'Power supply [{#DURABLE.ID}]: Serial number'
              type: DEPENDENT
              key: 'hpe.msa.power_supplies["{#DURABLE.ID}",serial_number]'
              value_type: CHAR
              description: 'Power supply serial number.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''serial-number'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1d
              master_item:
                key: 'hpe.msa.get.power_supplies["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: power-supply
                - tag: power-supply
                  value: '{#DURABLE.ID}'
            - uuid: a3ff6ab5576246fe9e794e01df4fe1b9
              name: 'Power supply [{#DURABLE.ID}]: Status'
              type: DEPENDENT
              key: 'hpe.msa.power_supplies["{#DURABLE.ID}",status]'
              description: 'Power supply status.'
              valuemap:
                name: Status
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''status-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.power_supplies["{#DURABLE.ID}",data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: power-supply
                - tag: power-supply
                  value: '{#DURABLE.ID}'
              trigger_prototypes:
                - uuid: 49c9d2d61c45476da5564299b2eebdee
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.power_supplies["{#DURABLE.ID}",status])=2'
                  name: 'Power supply [{#DURABLE.ID}]: Power supply has error status'
                  priority: AVERAGE
                  description: 'Power supply has error status.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: d6cbaeb5aab84e5eb487af4bf319d640
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.power_supplies["{#DURABLE.ID}",status])=4'
                  name: 'Power supply [{#DURABLE.ID}]: Power supply has unknown status'
                  priority: INFO
                  description: 'Power supply has unknown status.'
                  tags:
                    - tag: scope
                      value: notice
                - uuid: b7e85e7a6c254aba930d7704c58adf47
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.power_supplies["{#DURABLE.ID}",status])=1'
                  name: 'Power supply [{#DURABLE.ID}]: Power supply has warning status'
                  priority: WARNING
                  description: 'Power supply has warning status.'
                  tags:
                    - tag: scope
                      value: performance
          master_item:
            key: hpe.msa.get.power_supplies
          lld_macro_paths:
            - lld_macro: '{#DURABLE.ID}'
              path: '$.[''durable-id'']'
        - uuid: b132a010c8a84da79eee1ba725301be9
          name: 'Volumes discovery'
          type: DEPENDENT
          key: hpe.msa.volumes.discovery
          description: 'Discover volumes.'
          item_prototypes:
            - uuid: df0b425817414f3cae218f4269e9068f
              name: 'Volume [{#NAME}]: Get statistics data'
              type: DEPENDENT
              key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered volume statistics data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@[''volume-name''] == "{#NAME}")].first()'
              master_item:
                key: hpe.msa.get.volumes.statistics
              tags:
                - tag: component
                  value: raw
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: c5e4998ee3e44a2fa82facfceb465ffd
              name: 'Volume [{#NAME}]: Get data'
              type: DEPENDENT
              key: 'hpe.msa.get.volumes["{#NAME}",data]'
              history: '0'
              value_type: TEXT
              description: 'The discovered volume data.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[?(@[''volume-name''] == "{#NAME}")].first()'
              master_item:
                key: hpe.msa.get.volumes
              tags:
                - tag: component
                  value: raw
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: cc6c4bddc05243c7a90082a3450a76a7
              name: 'Volume [{#NAME}]: Blocks allocated'
              type: DEPENDENT
              key: 'hpe.msa.volumes.blocks["{#NAME}",allocated]'
              description: 'The amount of blocks currently allocated to the volume.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''allocated-size-numeric'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 900d94185fa9480590915bbafb8ccda0
              name: 'Volume [{#NAME}]: Blocks size'
              type: DEPENDENT
              key: 'hpe.msa.volumes.blocks["{#NAME}",size]'
              units: B
              description: 'The size of a block, in bytes.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocksize'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 5cdae787c8b6485899f8f4e8c3cf6b71
              name: 'Volume [{#NAME}]: Blocks total'
              type: DEPENDENT
              key: 'hpe.msa.volumes.blocks["{#NAME}",total]'
              description: 'Total space in blocks.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''blocks'']'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: b7615bb6a3434303a2bb4751e7aed458
              name: 'Volume [{#NAME}]: Cache: Read hits, rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.cache.read.hits["{#NAME}",rate]'
              description: 'For the controller that owns the volume, the number of times the block to be read is found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''read-cache-hits'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 655e319736804d8db4b6988f7205c5e3
              name: 'Volume [{#NAME}]: Cache: Read misses, rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.cache.read.misses["{#NAME}",rate]'
              description: 'For the controller that owns the volume, the number of times the block to be read is not found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''read-cache-misses'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 849ef4370f4b46ea894d2a2e1e4a3ea4
              name: 'Volume [{#NAME}]: Cache: Write hits, rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.cache.write.hits["{#NAME}",rate]'
              description: 'For the controller that owns the volume, the number of times the block written to is found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''write-cache-hits'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 593f4fce31f24e9b99c9bc69d2ead38b
              name: 'Volume [{#NAME}]: Cache: Write misses, rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.cache.write.misses["{#NAME}",rate]'
              description: 'For the controller that owns the volume, the number of times the block written to is not found in cache per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''write-cache-misses'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 1a810fe32e464e8cbcdfc61769bc7869
              name: 'Volume [{#NAME}]: Data transfer rate: Reads'
              type: DEPENDENT
              key: 'hpe.msa.volumes.data_transfer.reads["{#NAME}",rate]'
              value_type: FLOAT
              units: Bps
              description: 'The data read rate, in bytes per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''data-read-numeric'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 4dd1d47335a9425a94ffcee4c8ed2216
              name: 'Volume [{#NAME}]: Data transfer rate: Total'
              type: DEPENDENT
              key: 'hpe.msa.volumes.data_transfer.total["{#NAME}",rate]'
              units: Bps
              description: 'The data transfer rate, in bytes per second, calculated over the interval since these statistics were last requested or reset. This value will be zero if it has not been requested or reset since a controller restart.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''bytes-per-second-numeric'']'
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: d5198b50ba8f4db1aa160d0208540a74
              name: 'Volume [{#NAME}]: Data transfer rate: Writes'
              type: DEPENDENT
              key: 'hpe.msa.volumes.data_transfer.writes["{#NAME}",rate]'
              value_type: FLOAT
              units: Bps
              description: 'The data write rate, in bytes per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''data-written-numeric'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 00f5c3f9d19d450e999c389ba297fb41
              name: 'Volume [{#NAME}]: IOPS, read rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.iops.read["{#NAME}",rate]'
              value_type: FLOAT
              units: '!r/s'
              description: 'Number of read operations per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-reads'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: b925122eda0c4c1380b843bc764ed122
              name: 'Volume [{#NAME}]: IOPS, total rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.iops.total["{#NAME}",rate]'
              units: '!iops'
              description: 'Total input/output operations per second, calculated over the interval since these statistics were last requested or reset. This value will be zero if it has not been requested or reset since a controller restart.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''iops'']'
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: a9fcc1525204489cad52cf4e88518064
              name: 'Volume [{#NAME}]: IOPS, write rate'
              type: DEPENDENT
              key: 'hpe.msa.volumes.iops.write["{#NAME}",rate]'
              value_type: FLOAT
              units: '!w/s'
              description: 'Number of write operations per second.'
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''number-of-writes'']'
                - type: CHANGE_PER_SECOND
              master_item:
                key: 'hpe.msa.get.volumes.statistics["{#NAME}",data]'
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 860855a80c554e0685d4d4125342b547
              name: 'Volume [{#NAME}]: Space allocated'
              type: CALCULATED
              key: 'hpe.msa.volumes.space["{#NAME}",allocated]'
              units: B
              params: 'last(//hpe.msa.volumes.blocks["{#NAME}",size])*last(//hpe.msa.volumes.blocks["{#NAME}",allocated])'
              description: 'The amount of space currently allocated to the volume.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: eb09d8791bb84c8aadf5cdcac3d76413
              name: 'Volume [{#NAME}]: Space total'
              type: CALCULATED
              key: 'hpe.msa.volumes.space["{#NAME}",total]'
              units: B
              params: 'last(//hpe.msa.volumes.blocks["{#NAME}",size])*last(//hpe.msa.volumes.blocks["{#NAME}",total])'
              description: 'The capacity of the volume.'
              preprocessing:
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              tags:
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
            - uuid: 096824dbf7ac4bdba4b0ce5b55c2f53d
              name: 'Volume [{#NAME}]: Health'
              type: DEPENDENT
              key: 'hpe.msa.volumes["{#DURABLE.ID}",health]'
              description: 'Volume health status.'
              valuemap:
                name: Health
              preprocessing:
                - type: JSONPATH
                  parameters:
                    - '$.[''health-numeric'']'
                  error_handler: CUSTOM_VALUE
                  error_handler_params: '4'
                - type: DISCARD_UNCHANGED_HEARTBEAT
                  parameters:
                    - 1h
              master_item:
                key: 'hpe.msa.get.volumes["{#NAME}",data]'
              tags:
                - tag: component
                  value: health
                - tag: component
                  value: volume
                - tag: volume
                  value: '{#NAME}'
              trigger_prototypes:
                - uuid: 79ead823825f456c92f336f684c6d240
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.volumes["{#DURABLE.ID}",health])=1'
                  name: 'Volume [{#NAME}]: Volume health is in degraded state'
                  priority: WARNING
                  description: 'Volume health is in degraded state.'
                  tags:
                    - tag: scope
                      value: performance
                - uuid: 0f72a4a7263445a993f079b9548667ac
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.volumes["{#DURABLE.ID}",health])=2'
                  name: 'Volume [{#NAME}]: Volume health is in fault state'
                  priority: AVERAGE
                  description: 'Volume health is in fault state.'
                  tags:
                    - tag: scope
                      value: availability
                - uuid: f02eaa08134a4fa08b40643275e9841f
                  expression: 'last(/HPE MSA 2060 Storage by HTTP/hpe.msa.volumes["{#DURABLE.ID}",health])=3'
                  name: 'Volume [{#NAME}]: Volume health is in unknown state'
                  priority: INFO
                  description: 'Volume health is in unknown state.'
                  tags:
                    - tag: scope
                      value: notice
          graph_prototypes:
            - uuid: 8905b826b774473991f74b927716322e
              name: 'Volume [{#NAME}]: Cache usage'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.cache.read.hits["{#NAME}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.cache.read.misses["{#NAME}",rate]'
                - sortorder: '2'
                  color: 00611C
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.cache.write.hits["{#NAME}",rate]'
                - sortorder: '3'
                  color: F7941D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.cache.write.misses["{#NAME}",rate]'
            - uuid: 1bd9df7bab9c4f3a978810c82cc61f42
              name: 'Volume [{#NAME}]: Data transfer rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.data_transfer.reads["{#NAME}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.data_transfer.writes["{#NAME}",rate]'
            - uuid: 24dfc70c5d724f13ac1cec6b229c7fe9
              name: 'Volume [{#NAME}]: Disk operations rate'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.iops.read["{#NAME}",rate]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.iops.write["{#NAME}",rate]'
            - uuid: 5a316cdf8c6f42acb3cb7a158861145a
              name: 'Volume [{#NAME}]: Space utilization'
              graph_items:
                - color: 199C0D
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.space["{#NAME}",allocated]'
                - sortorder: '1'
                  color: F63100
                  item:
                    host: 'HPE MSA 2060 Storage by HTTP'
                    key: 'hpe.msa.volumes.space["{#NAME}",total]'
          master_item:
            key: hpe.msa.get.volumes
          lld_macro_paths:
            - lld_macro: '{#NAME}'
              path: '$.[''volume-name'']'
      tags:
        - tag: class
          value: storage
        - tag: target
          value: hpe
        - tag: target
          value: msa-2060
      macros:
        - macro: '{$HPE.MSA.API.HOST}'
          value: '<SET API HOST>'
          description: 'The hostname or IP address of the API host.'
        - macro: '{$HPE.MSA.API.PASSWORD}'
          type: SECRET_TEXT
          description: 'Specify password for API.'
        - macro: '{$HPE.MSA.API.PORT}'
          value: '443'
          description: 'Connection port for API.'
        - macro: '{$HPE.MSA.API.SCHEME}'
          value: https
          description: 'Connection scheme for API.'
        - macro: '{$HPE.MSA.API.USERNAME}'
          value: zabbix
          description: 'Specify user name for API.'
        - macro: '{$HPE.MSA.CONTROLLER.CPU.UTIL.CRIT}'
          value: '90'
          description: 'The critical threshold of the CPU utilization expressed in %.'
        - macro: '{$HPE.MSA.DATA.TIMEOUT}'
          value: 30s
          description: 'Response timeout for API.'
        - macro: '{$HPE.MSA.DISKS.GROUP.PUSED.MAX.CRIT}'
          value: '90'
          description: 'The critical threshold of the disk group space utilization in %.'
        - macro: '{$HPE.MSA.DISKS.GROUP.PUSED.MAX.WARN}'
          value: '80'
          description: 'The warning threshold of the disk group space utilization in %.'
        - macro: '{$HPE.MSA.POOL.PUSED.MAX.CRIT}'
          value: '90'
          description: 'The critical threshold of the pool space utilization in %.'
        - macro: '{$HPE.MSA.POOL.PUSED.MAX.WARN}'
          value: '80'
          description: 'The warning threshold of the pool space utilization in %.'
      dashboards:
        - uuid: f14141c1d6d44e8a9fc7c874487f435b
          name: 'Storage overview'
          auto_start: 'NO'
          pages:
            - name: Controllers
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Controller [{#CONTROLLER.ID}]: Cache: Write utilization'
                    - type: STRING
                      name: reference
                      value: AAAAA
                - type: graphprototype
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Controller [{#CONTROLLER.ID}]: Cache usage'
                    - type: STRING
                      name: reference
                      value: AAAAB
                - type: graphprototype
                  'y': '10'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Controller [{#CONTROLLER.ID}]: Controller CPU utilization'
                    - type: STRING
                      name: reference
                      value: AAAAC
                - type: graphprototype
                  'y': '15'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Controller [{#CONTROLLER.ID}]: Data transfer rate'
                    - type: STRING
                      name: reference
                      value: AAAAD
                - type: graphprototype
                  'y': '20'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Controller [{#CONTROLLER.ID}]: Disk operations rate'
                    - type: STRING
                      name: reference
                      value: AAAAE
            - name: 'Disk groups'
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Disk group [{#NAME}]: Average response time'
                    - type: STRING
                      name: reference
                      value: AAAAF
                - type: graphprototype
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Disk group [{#NAME}]: Data transfer rate'
                    - type: STRING
                      name: reference
                      value: AAAAG
                - type: graphprototype
                  'y': '10'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Disk group [{#NAME}]: Disk operations rate'
                    - type: STRING
                      name: reference
                      value: AAAAH
                - type: graphprototype
                  'y': '15'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Disk group [{#NAME}]: Space utilization'
                    - type: STRING
                      name: reference
                      value: AAAAI
            - name: Fans
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Fan [{#DURABLE.ID}]: Speed'
                    - type: STRING
                      name: reference
                      value: AAAAJ
            - name: Pools
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Pool [{#NAME}]: Space utilization'
                    - type: STRING
                      name: reference
                      value: AAAAK
            - name: Volumes
              widgets:
                - type: graphprototype
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Volume [{#NAME}]: Cache usage'
                    - type: STRING
                      name: reference
                      value: AAAAL
                - type: graphprototype
                  'y': '5'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Volume [{#NAME}]: Data transfer rate'
                    - type: STRING
                      name: reference
                      value: AAAAM
                - type: graphprototype
                  'y': '10'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Volume [{#NAME}]: Disk operations rate'
                    - type: STRING
                      name: reference
                      value: AAAAN
                - type: graphprototype
                  'y': '15'
                  width: '72'
                  height: '5'
                  fields:
                    - type: INTEGER
                      name: columns
                      value: '1'
                    - type: GRAPH_PROTOTYPE
                      name: graphid.0
                      value:
                        host: 'HPE MSA 2060 Storage by HTTP'
                        name: 'Volume [{#NAME}]: Space utilization'
                    - type: STRING
                      name: reference
                      value: AAAAO
      valuemaps:
        - uuid: f7af1259f3c54a5faa040c743d386d1d
          name: 'Controller status'
          mappings:
            - value: '0'
              newvalue: Operational
            - value: '1'
              newvalue: Down
            - value: '2'
              newvalue: 'Not Installed'
        - uuid: 6bb0dfe12f4249ef9f4b804885c70c60
          name: 'Disk group status'
          mappings:
            - value: '0'
              newvalue: FTOL
            - value: '1'
              newvalue: FTDN
            - value: '2'
              newvalue: CRIT
            - value: '3'
              newvalue: OFFL
            - value: '4'
              newvalue: QTCR
            - value: '5'
              newvalue: QTOF
            - value: '6'
              newvalue: QTDN
            - value: '7'
              newvalue: STOP
            - value: '8'
              newvalue: MSNG
            - value: '9'
              newvalue: DMGD
            - value: '11'
              newvalue: QTDN
            - value: '250'
              newvalue: UP
        - uuid: de0e7d801a9b42cf80fe4c71c0eed982
          name: 'Disk temperature status'
          mappings:
            - value: '1'
              newvalue: OK
            - value: '2'
              newvalue: Critical
            - value: '3'
              newvalue: Warning
            - value: '4'
              newvalue: Unknown
        - uuid: 10547e62c7bb4581b347bc523ef03582
          name: 'Disk type'
          mappings:
            - value: '4'
              newvalue: SAS
            - value: '8'
              newvalue: 'SSD SAS'
            - value: '11'
              newvalue: 'SAS MDL'
        - uuid: 37317f19f7d74b8fa61dd1b28e6f4d42
          name: 'Enclosure status'
          mappings:
            - value: '0'
              newvalue: Unsupported
            - value: '1'
              newvalue: OK
            - value: '2'
              newvalue: Critical
            - value: '3'
              newvalue: Warning
            - value: '4'
              newvalue: Unrecoverable
            - value: '5'
              newvalue: 'Not installed'
            - value: '6'
              newvalue: Unknown
            - value: '7'
              newvalue: Unavailable
        - uuid: 1acc14c82fba4c3daa207d0ce9b702f2
          name: 'Fan status'
          mappings:
            - value: '0'
              newvalue: Up
            - value: '1'
              newvalue: Error
            - value: '2'
              newvalue: 'Off'
            - value: '3'
              newvalue: Missing
        - uuid: 284ed898fb7c46ecb8d719646445264c
          name: 'FRU status'
          mappings:
            - value: '0'
              newvalue: 'Invalid data'
            - value: '1'
              newvalue: Fault
            - value: '2'
              newvalue: Absent
            - value: '3'
              newvalue: 'Power off'
            - value: '4'
              newvalue: OK
        - uuid: cb8c3d00dfd4456181765b8b350ea4d2
          name: Health
          mappings:
            - value: '0'
              newvalue: OK
            - value: '1'
              newvalue: Degraded
            - value: '2'
              newvalue: Fault
            - value: '3'
              newvalue: Unknown
            - value: '4'
              newvalue: N/A
        - uuid: ec101e7d212747779ed56ef9dbf72e2b
          name: 'Port type'
          mappings:
            - value: '0'
              newvalue: Unknown
            - value: '6'
              newvalue: FC
            - value: '8'
              newvalue: SAS
            - value: '9'
              newvalue: iSCSI
        - uuid: 171c9abf20514b0fb78d532bd987881b
          name: 'RAID type'
          mappings:
            - value: '0'
              newvalue: RAID0
            - value: '1'
              newvalue: RAID1
            - value: '2'
              newvalue: MSA-DP+
            - value: '5'
              newvalue: RAID5
            - value: '6'
              newvalue: NRAID
            - value: '10'
              newvalue: RAID10
            - value: '11'
              newvalue: RAID6
        - uuid: 402b0dacf14a4436b0d3cfe237bf1e86
          name: Status
          mappings:
            - value: '0'
              newvalue: Up
            - value: '1'
              newvalue: Warning
            - value: '2'
              newvalue: Error
            - value: '3'
              newvalue: 'Not present'
            - value: '4'
              newvalue: Unknown
            - value: '6'
              newvalue: Disconnected
